@@ -3,7 +3,7 @@
  * Kronolith_Driver defines an API for implementing storage backends for
  * Kronolith.
  *
- * $Horde: kronolith/lib/Driver.php,v 1.116.2.83 2009/04/29 14:57:10 jan Exp $
+ * $Horde: kronolith/lib/Driver.php,v 1.116.2.86 2010/04/22 10:56:48 jan Exp $
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jan Schneider <jan@horde.org>
@@ -529,13 +529,15 @@ class Kronolith_Event {
         $result = $driver->saveEvent($this);
         if (!is_a($result, 'PEAR_Error') &&
             !empty($GLOBALS['conf']['alarms']['driver'])) {
+            require_once 'Horde/Alarm.php';
+            $horde_alarm = Horde_Alarm::factory();
             $alarm = $this->toAlarm(new Horde_Date($_SERVER['REQUEST_TIME']));
             if ($alarm) {
                 $alarm['start'] = new Horde_Date($alarm['start']);
                 $alarm['end'] = new Horde_Date($alarm['end']);
-                require_once 'Horde/Alarm.php';
-                $horde_alarm = Horde_Alarm::factory();
                 $horde_alarm->set($alarm);
+            } else {
+                $horde_alarm->delete($this->_uid);
             }
         }
 
@@ -1838,7 +1840,12 @@ class Kronolith_Event {
 
         // Alarm.
         if (Util::getFormData('alarm') == 1) {
-            $this->setAlarm(Util::getFormData('alarm_value') * Util::getFormData('alarm_unit'));
+            $alarm = Util::getFormData('alarm_value');
+            if ($alarm == 0) {
+                $this->setAlarm(1);
+            } else {
+                $this->setAlarm($alarm * Util::getFormData('alarm_unit'));
+            }
         } else {
             $this->setAlarm(0);
         }
@@ -1848,6 +1855,8 @@ class Kronolith_Event {
         if ($recur !== null && $recur !== '') {
             if (!isset($this->recurrence)) {
                 $this->recurrence = new Horde_Date_Recurrence($this->start);
+            } else {
+                $this->recurrence->setRecurStart($this->start);
             }
             if (Util::getFormData('recur_enddate_type') == 'date') {
                 $recur_enddate = Util::getFormData('recur_enddate');
@@ -2226,13 +2235,16 @@ class Kronolith_Event {
             $from_url = Horde::selfUrl(true, false, true);
         }
 
-        $link = '';
         $event_title = $this->getTitle();
+        $view_url = $this->getViewUrl(array('timestamp' => $timestamp, 'url' => $from_url), $full);
+        $read_permission = $this->hasPermission(PERMS_READ);
+
+        $link = '';
         if (isset($this->external)) {
             $link = $registry->link($this->external . '/show', $this->external_params);
             $link = Horde::linkTooltip(Horde::url($link), '', 'event-tentative', '', '', String::wrap($this->description));
-        } elseif (isset($this->eventID) && $this->hasPermission(PERMS_READ)) {
-            $link = Horde::linkTooltip($this->getViewUrl(array('timestamp' => $timestamp, 'url' => $from_url), $full),
+        } elseif (isset($this->eventID) && $read_permission) {
+            $link = Horde::linkTooltip($view_url,
                                        $event_title,
                                        $this->getStatusClass(), '', '',
                                        $this->getTooltip());
@@ -2240,9 +2252,7 @@ class Kronolith_Event {
 
         $link .= @htmlspecialchars($event_title, ENT_QUOTES, NLS::getCharset());
 
-        if ($this->hasPermission(PERMS_READ) &&
-            (isset($this->eventID) ||
-             isset($this->external))) {
+        if ($read_permission && (isset($this->eventID) || isset($this->external))) {
             $link .= '</a>';
         }
 
@@ -2250,6 +2260,7 @@ class Kronolith_Event {
             $icon_color = isset($GLOBALS['cManager_fgColors'][$this->category]) ?
                 ($GLOBALS['cManager_fgColors'][$this->category] == '#000' ? '000' : 'fff') :
                 ($GLOBALS['cManager_fgColors']['_default_'] == '#000' ? '000' : 'fff');
+            $image_dir = Horde::url($registry->getImageDir(), true, -1);
 
             $status = '';
             if ($this->alarm) {
@@ -2277,7 +2288,7 @@ class Kronolith_Event {
                 $status .= Horde::img('alarm-' . $icon_color . '.png', $title,
                                       array('title' => $title,
                                             'class' => 'iconAlarm'),
-                                      Horde::url($registry->getImageDir(), true, -1));
+                                      $image_dir);
             }
 
             if ($this->recurs()) {
@@ -2285,7 +2296,7 @@ class Kronolith_Event {
                 $status .= Horde::img('recur-' . $icon_color . '.png', $title,
                                       array('title' => $title,
                                             'class' => 'iconRecur'),
-                                      Horde::url($registry->getImageDir(), true, -1));
+                                      $image_dir);
             }
 
             if ($this->isPrivate()) {
@@ -2293,7 +2304,7 @@ class Kronolith_Event {
                 $status .= Horde::img('private-' . $icon_color . '.png', $title,
                                       array('title' => $title,
                                             'class' => 'iconPrivate'),
-                                      Horde::url($registry->getImageDir(), true, -1));
+                                      $image_dir);
             }
 
             if (!empty($this->attendees)) {
@@ -2303,7 +2314,7 @@ class Kronolith_Event {
                 $status .= Horde::img('attendees.png', $title,
                                       array('title' => $title,
                                             'class' => 'iconPeople'),
-                                      Horde::url($registry->getImageDir(), true, -1));
+                                      $image_dir);
             }
 
             if (!empty($status)) {
@@ -2318,17 +2329,15 @@ class Kronolith_Event {
             $delete = '';
             if ((!$this->isPrivate() || $this->getCreatorId() == Auth::getAuth())
                 && $this->hasPermission(PERMS_EDIT)) {
-                $editurl = $this->getEditUrl(array('timestamp' => $timestamp,
-                                                   'url' => $from_url));
+                $editurl = Util::addParameter($view_url, 'view', 'EditEvent', !$full);
                 $edit = Horde::link($editurl, sprintf(_("Edit %s"), $event_title), 'iconEdit')
-                    . Horde::img('edit-' . $icon_color . '.png', _("Edit"), '', Horde::url($registry->getImageDir(), true, -1))
+                    . Horde::img('edit-' . $icon_color . '.png', _("Edit"), '', $image_dir)
                     . '</a>';
             }
             if ($this->hasPermission(PERMS_DELETE)) {
-                $delurl = $this->getDeleteUrl(array('timestamp' => $timestamp,
-                                                    'url' => $from_url));
+                $delurl = Util::addParameter($view_url, 'view', 'DeleteEvent', !$full);
                 $delete = Horde::link($delurl, sprintf(_("Delete %s"), $event_title), 'iconDelete')
-                    . Horde::img('delete-' . $icon_color . '.png', _("Delete"), '', Horde::url($registry->getImageDir(), true, -1))
+                    . Horde::img('delete-' . $icon_color . '.png', _("Delete"), '', $image_dir)
                     . '</a>';
             }
 
