@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: kronolith/lib/Kronolith.php,v 1.263.2.81 2009/03/25 23:49:29 jan Exp $
+ * $Horde: kronolith/lib/Kronolith.php,v 1.263.2.84 2009/11/25 10:21:36 jan Exp $
  *
  * @package Kronolith
  */
@@ -346,8 +346,13 @@ class Kronolith {
         foreach ($GLOBALS['all_external_calendars'] as $api => $categories) {
             foreach ($categories as $id => $name) {
                 $calendarId = $api . '/' . $id;
-                if (in_array($calendarId, $_temp)) {
-                    $GLOBALS['display_external_calendars'][] = $calendarId;
+                /* Forward compatible checking of subscribed external
+                 * sources. */
+                foreach ($_temp as $_temp_cal) {
+                    if (strpos($_temp_cal, $calendarId) === 0 &&
+                        !in_array($calendarId, $GLOBALS['display_external_calendars'])) {
+                        $GLOBALS['display_external_calendars'][] = $calendarId;
+                    }
                 }
             }
         }
@@ -747,7 +752,7 @@ class Kronolith {
                         }
 
                         $event = &$kronolith_driver->getEvent();
-
+                        $event->setAlarm(0);
                         if ($GLOBALS['prefs']->getValue('show_external_colors') &&
                             isset($eventsListItem['category'])) {
                             $event->category = $eventsListItem['category'];
@@ -796,7 +801,9 @@ class Kronolith {
             /* Remote Calendars. */
             foreach ($GLOBALS['display_remote_calendars'] as $url) {
                 $events = Kronolith::listRemoteEvents($url);
-                if (!is_a($events, 'PEAR_Error')) {
+                if (is_a($events, 'PEAR_Error')) {
+                    $GLOBALS['notification']->push($events, 'horde.warning');
+                } else {
                     $kronolith_driver->open(Kronolith::getDefaultCalendar(PERMS_SHOW));
                     foreach ($events as $event) {
 
