@@ -1,11 +1,13 @@
 <?php
 /**
- * $Horde: kronolith/search.php,v 1.8.4.3 2005/08/08 16:51:12 chuck Exp $
+ * $Horde: kronolith/search.php,v 1.8.4.9 2009/01/06 15:24:43 jan Exp $
  *
- * Copyright 2004-2005 Meilof Veeningen <meilof@wanadoo.nl>
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL).  If you
+ * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ *
+ * @author Meilof Veeningen <meilof@gmail.com>
  */
 
 /**
@@ -13,10 +15,8 @@
  */
 function _sortEvents($a, $b)
 {
-    global $event;
-
-    $start_a = $a->nextRecurrence($event->start);
-    $start_b = $b->nextRecurrence($event->start);
+    $start_a = $a->recurs() ? $a->recurrence->nextRecurrence($GLOBALS['event']->start) : $a->start;
+    $start_b = $b->recurs() ? $b->recurrence->nextRecurrence($GLOBALS['event']->start) : $b->start;
     $diff = $start_a->timestamp() - $start_b->timestamp();
     if ($diff == 0) {
         return strcoll($a->title, $b->title);
@@ -28,14 +28,12 @@ function _sortEvents($a, $b)
 @define('KRONOLITH_BASE', dirname(__FILE__));
 require_once KRONOLITH_BASE . '/lib/base.php';
 
-$colors = $cManager->colors();
-
 /* Get search parameters. */
 $search_mode = Util::getFormData('search_mode', 'basic');
 
 if ($search_mode != 'basic') {
     /* Make a new empty event object with default values. */
-    $event = &$kronolith->getEvent();
+    $event = &$kronolith_driver->getEvent();
     $event->title = $event->calendars = $event->category = $event->location =
     $event->status = $event->description = null;
 
@@ -65,24 +63,24 @@ $desc = Util::getFormData('pattern_desc');
 $title = Util::getFormData('pattern_title');
 if ($desc || $title) {
     /* We're doing a simple search. */
-    $event = &$kronolith->getEvent();
+    $event = &$kronolith_driver->getEvent();
     $event->setDescription($desc);
     $event->setTitle($title);
     $event->category = null;
     $event->status = null;
 
-    $time1 = time();
+    $time1 = $_SERVER['REQUEST_TIME'];
     $range = Util::getFormData('range');
     if ($range == '+') {
-        $event->start = &new Horde_Date($time1);
+        $event->start = new Horde_Date($time1);
         $event->end = null;
     } elseif ($range == '-') {
         $event->start = null;
-        $event->end = &new Horde_Date($time1);
+        $event->end = new Horde_Date($time1);
     } else {
         $time2 = $time1 + $range;
-        $event->start = &new Horde_Date(min($time1, $time2));
-        $event->end = &new Horde_Date(max($time1, $time2));
+        $event->start = new Horde_Date(min($time1, $time2));
+        $event->end = new Horde_Date(max($time1, $time2));
     }
     $events = Kronolith::search($event);
 } elseif (isset($q_title)) {
@@ -95,12 +93,13 @@ Horde::addScriptFile('tooltip.js', 'horde', true);
 require KRONOLITH_TEMPLATES . '/common-header.inc';
 require KRONOLITH_TEMPLATES . '/menu.inc';
 
+echo '<div id="page">';
 if ($search_mode == 'basic') {
     require KRONOLITH_TEMPLATES . '/search/search.inc';
-    $notification->push('document.event.pattern_title.focus()', 'javascript');
+    $notification->push('document.eventform.pattern_title.focus()', 'javascript');
 } else {
     require KRONOLITH_TEMPLATES . '/search/search_advanced.inc';
-    $notification->push('document.event.title.focus()', 'javascript');
+    $notification->push('document.eventform.title.focus()', 'javascript');
 }
 
 /* Display search results. */
@@ -112,11 +111,8 @@ if (isset($events)) {
         require KRONOLITH_TEMPLATES . '/search/event_headers.inc';
 
         foreach ($events as $found) {
-            $start = $found->nextRecurrence($event->start);
+            $start = $found->recurs() ? $found->recurrence->nextRecurrence($event->start) : $found->start;
             $end = &new Horde_Date($start->timestamp() + $found->durMin * 60);
-            $color = isset($colors[$found->getCategory()])
-                ? $colors[$found->getCategory()]
-                : $colors['_default_'];
             require KRONOLITH_TEMPLATES . '/search/event_summaries.inc';
         }
         require KRONOLITH_TEMPLATES . '/search/event_footers.inc';
@@ -125,4 +121,6 @@ if (isset($events)) {
     }
 }
 
+echo '</div>';
+require KRONOLITH_TEMPLATES . '/panel.inc';
 require $registry->get('templates', 'horde') . '/common-footer.inc';
